# -*- coding: iso-8859-1 -*-
"""
    MoinMoin ubuntu theme

    @copyright: (c) 2003-2004 by Nir Soffer, Thomas Waldmann
    @license: GNU GPL, see COPYING for details.

    Borrows heavily from modern, a bit from Classic, and has a few 
    things of its own.
"""

from MoinMoin.theme import ThemeBase
from MoinMoin import wikiutil
from MoinMoin.Page import Page


class Theme(ThemeBase):

    name = 'light'

# Overriding theme/__init__.py #########################################

    # fake _ function to get gettext recognize those texts:
    _ = lambda x: x
       
    # TODO: remove icons that are not used any more.
    icons = {
        # key         alt                        icon filename      w   h
        # ------------------------------------------------------------------
        # navibar
        'help':       ("%(page_help_contents)s", "s-help.png",         20, 20),
        'find':       ("%(page_find_page)s",     "s-search.png",       20, 20),
        'diff':       (_("Diffs"),               "u-diff.png",         22, 22),
        'info':       (_("Info"),                "u-info.png",         22, 22),
        'edit':       (_("Edit"),                "u-edit.png",         20, 20),
        'unsubscribe':(_("Unsubscribe"),         "u-unsubscribe.png",  23, 21),
        'subscribe':  (_("Subscribe"),           "u-subscribe_dk.png", 23, 21),
        'raw':        (_("Raw"),                 "u-raw.png",          21, 23),
        'xml':        (_("XML"),                 "moin-xml2.png",      36, 14),
        'print':      (_("Print"),               "u-print.png",        20, 20),
        'view':       (_("View"),                "u-show.png",         20, 20),
        'home':       (_("Home"),                "u-home.png",         20, 20),
        'up':         (_("Up"),                  "u-parent.png",       20, 20),
        # FileAttach
        'attach':     ("%(attach_count)s",       "moin-attach.png",  7, 15),
        # RecentChanges
        'rss':        (_("[RSS]"),               "moin-rss.png",    36, 14),
        'deleted':    (_("[DELETED]"),           "u-deleted.png",      22, 22),
        'updated':    (_("[UPDATED]"),           "u-updated.png",      22, 22),
        'new':        (_("[NEW]"),               "u-new.png",          22, 22),
        'diffrc':     (_("[DIFF]"),              "u-diff.png",         22, 22),
        # General
        'bottom':     (_("[BOTTOM]"),            "u-bottom.png",       14, 10),
        'top':        (_("[TOP]"),               "u-top.png",          14, 10),
        'www':        ("[WWW]",                  "u-www.png",          16, 16),
        'mailto':     ("[MAILTO]",               "u-email.png",        23, 13),
        'news':       ("[NEWS]",                 "u-news.png",         16, 16),
        'telnet':     ("[TELNET]",               "u-telnet.png",       16, 16),
        'ftp':        ("[FTP]",                  "u-ftp.png",          16, 16),
        'file':       ("[FILE]",                 "u-ftp.png",          16, 16),
        # search forms
        'searchbutton': ("[?]",                  "s-search.png",       20, 20),
        'interwiki':  ("[%(wikitag)s]",          "u-inter.png",        16, 16),
        # smileys
        'X-(': ("Angry X-(","icon_mad.png",16,16),
        ':D': ("Big Grin :)","icon_biggrin.png",16,16),
        '<:(': ("Sad <:(","icon_sad.png",16,16),
        ':o': ("Surprised :o","icon_surprised.png",16,16),
        ':(': ("Sad :(","icon_sad.png",16,16),
        ':)': ("Smile :)","icon_smile.png",16,16),
        'B)': ("Awesome! B)","icon_cool.png",16,16),
        ':))': ("Funny :))","icon_razz.png",16,16),
        ';)': ("Wink ;)","icon_wink.png",16,16),
        '/!\\': ("Warning /!\\","icon_eek.png",16,16),
        '<!>': ("Info <!>","icon_cool.png",16,16),
        '(!)': ("Info (!)","icon_cool.png",16,16),
        ':-?': ("Tongue out :-?","icon_razz.png",16,16),
        '>:>': ("Angry >:>","icon_mad.png",16,16),#think this is meant to be devilish or something
        '|)': ("Smile |)","icon_smile.png",16,16),
        ':-(': ("Sad :-(","icon_sad.png",16,16),
        ':-)': ("Smile :-)","icon_smile.png",16,16),
        'B-)': ("Awesome B-)","icon_cool.png",16,16),
        ':\\': ("Confused :\\","icon_confused.png",16,16),
        ':-))': ("Funny :))","icon_razz.png",16,16),
        ';-)': ("Wink ;-)","icon_wink.png",16,16),
        '|-)': ("Smile |-)","icon_smile.png",16,16),
        '{*}': ("Ubuntu","icon_cof.png", 16,16),
        'renamed': ("Renamed","moin-renamed.png", 60,12),
        'conflict': ("Conflict","moin-conflict.png", 60,12),
        '(./)': ("(./)","checkmark.png", 16,16),
        '{OK}': ("(OK)","thumbs-up.png", 16,16),
        '{X}': ("(X)","icon-error.png", 16,16),
        '{i}': ("(i)","icon-info.png", 16,16), 
        '{1}': ("(1)","prio1.png", 16,16),
        '{2}': ("(2)","prio2.png", 16,16),
        '{3}': ("(3)","prio3.png", 16,16),
        '{o}': ("(o)","star_off.png", 16,16),
    }
    del _

# Public functions #####################################################

    def header(self, d, **kw):
        """ Assemble wiki header
        
        @param d: parameter dictionary
        @rtype: unicode
        @return: page header html
        """
        html = [
            # Pre header custom html
            self.emit_custom_html(self.cfg.page_header1),
            
            # Header
            u"""
    <div id="leftbanner">
    </div>
    <div id="rightbanner">
    </div>
    <div id="container">
        <div id="container-inner">
	    <div id="mothership">
		<ul>
	            <li><a href="https://partners.ubuntu.com">Partners</a> </li>
        	    <li><a href="https://www.ubuntu.com/support/community-support">Support</a></li>
        	    <li><a href="https://community.ubuntu.com">Community</a></li>
        	    <li><a href="https://www.ubuntu.com">Ubuntu.com</a></li>
	        </ul>
	    </div>
            <div id="header">
                <h1 id="ubuntu-header"><a href="https://help.ubuntu.com/">Ubuntu Documentation</a></h1>
                <ul id="main-menu">
                    <li><a href="https://help.ubuntu.com/">Official Documentation</a></li>
                    <li><a class="main-menu-item current" href="https://help.ubuntu.com/community/CommunityHelpWiki">Community Help Wiki</a></li>
                    <li><a href="https://community.ubuntu.com/t/contribute/26">Contribute</a></li>
                </ul>
            </div>
            <div id="menu-search">
                <div id="subheader"> 
                    <div class="subheader-menu"> 
                        <div id="second-nav">""",
            self.username(d),
            """ </div> 
    <div id="user-info"> 
    </div>
 

                            
                        </div> 
                    </div> 


                    <div id="search-box">""",
            self.searchform(d),
            """
                    </div>
                </div>
                <div id="title"><h1>""",
                self.title_with_separators(d),
            u"""</h1>
                </div>
            <div id="cwt-nav3">""",
            self.editbar(d),
            """ <hr class="clear" />
            </div>
                <div id="cwt-content" class="clearfix content-area">""",
                self.msg(d),
            
            # Start of page
            self.startPage(),
        ]
        return u'\n'.join(html)

    editorheader = header
        
    def searchform(self, d):
        """
        assemble Custom search form by Dustin Kirkland
	now works for browsers with and without javascript
        
        @param d: parameter dictionary
        @rtype: unicode
        @return: search form html
        """
        _ = self.request.getText
        form = self.request.form
        updates = {
            'search_label': _('Search:', formatted=False),
            'search_value': wikiutil.escape(form.get('value', [''])[0], 1),
            'search_full_label': _('Text', formatted=False),
            'search_title_label': _('Titles', formatted=False),
            'baseurl': self.request.getScriptname(),
            'pagename_quoted': wikiutil.quoteWikinameURL(d['page'].page_name),
            }
        d.update(updates)

        html = u'''
<noscript>
 <form action="http://www.google.com/cse" id="cse-search-box">
   <div>
     <input type="hidden" name="cx" value="003883529982892832976:e2vwumte3fq" />
     <input type="hidden" name="ie" value="UTF-8" />
     <input type="text" name="q" size="21" />
     <input type="submit" name="sa" value="Search" />
   </div>
 </form>
</noscript>

<script>
 document.write('<form action="https://help.ubuntu.com/search.html" id="cse-search-box">');
 document.write('  <div>');
 document.write('    <input type="hidden" name="cof" value="FORID:9" />');
 document.write('    <input type="hidden" name="cx" value="003883529982892832976:e2vwumte3fq" />');
 document.write('    <input type="hidden" name="ie" value="UTF-8" />');
 document.write('    <input type="text" name="q" size="21" />');
 document.write('    <input type="submit" name="sa" value="Search" />');
 document.write('  </div>');
 document.write('</form>');
</script>
''' % d
        return html

    def footer(self, d, **keywords):
        """ Assemble wiki footer
        
        @param d: parameter dictionary
        @keyword ...:...
        @rtype: unicode
        @return: page footer html
        """
        page = d['page']
        html = [
            # End of page
            self.endPage(),
            
            
            # Footer
            u"""
            </div>""",
            self.pageinfo(page),
            """</div>
            
            <div id="footer">
		<p>
		The material on this wiki is available under a free license, see <a href="https://help.ubuntu.com/community/
		License">Copyright / License</a> for details<br /><b>You</b> can contribute to this wiki, see 
		<a href="https://help.ubuntu.com/community/WikiGuide">Wiki Guide</a> for details
		</p>
            </div>

        </div>"""
        ]
        return u'\n'.join(html)

    # This is here to customise the text of the "Login" button for non-authenticated users and to add a "WikiGuide" link
    def username(self, d):
        """ Assemble the username / userprefs link

        @param d: parameter dictionary
        @rtype: unicode
        @return: username html
        """
        request = self.request
        _ = request.getText
        helpPage = wikiutil.getLocalizedPage(request, 'WikiGuide')
        userlinks = []
        # Add username/homepage link for registered users. We don't care
        # if it exists, the user can create it.
        if request.user.valid and request.user.name:
            interwiki = wikiutil.getInterwikiHomePage(request)
            name = request.user.name
            aliasname = request.user.aliasname
            if not aliasname:
                aliasname = name
            title = "%s @ %s" % (aliasname, interwiki[0])
            # link to (interwiki) user homepage
            homelink = (request.formatter.interwikilink(1, title=title, id="userhome", generated=True, *interwiki) +
                        request.formatter.text(name) +
                        request.formatter.interwikilink(0, title=title, id="userhome", *interwiki))
            userlinks.append(homelink)
            # link to userprefs action
            if 'userprefs' not in self.request.cfg.actions_excluded:
                userlinks.append(d['page'].link_to(request, text=_('Settings'),
                                               querystr={'action': 'userprefs'}, id='userprefs', rel='nofollow'))
            userlinks.append(helpPage.link_to(request, text=_("Wiki Guide")))

        if request.user.valid:
            if request.user.auth_method in request.cfg.auth_can_logout:
                userlinks.append(d['page'].link_to(request, text=_('Logout'),
                                                   querystr={'action': 'logout', 'logout': 'logout'}, id='logout', rel='nofollow'))
        else:
            query = {'action': 'login'}
            # special direct-login link if the auth methods want no input
            if request.cfg.auth_login_inputs == ['special_no_input']:
                query['login'] = '1'
            if request.cfg.auth_have_login:
                userlinks.append(self.infoLink(d['page']))
                userlinks.append(d['page'].link_to(request, text=_("Login to edit"),
                                                   querystr=query, id='login', rel='nofollow'))

        userlinks = [u'<li>%s</li>' % link for link in userlinks]
        html = u'<ul id="username">%s</ul>' % ''.join(userlinks)
        return html

    def editbar(self, d):
        """ Assemble the page edit bar.

        Create html on first call, then return cached html.

        @param d: parameter dictionary
        @rtype: unicode
        @return: iconbar html
        """
        page = d['page']
        request = self.request
        _ = request.getText
        if not self.shouldShowEditbar(page) or not request.user.valid:
            return ''

        html = self._cache.get('editbar')
        if html is None:
            # Remove empty items and format as list. The item for showing inline comments
            # is hidden by default. It gets activated through javascript only if inline
            # comments exist on the page.
            items = []
            for item in self.editbarItems(page):
                if item:
                    if 'nbcomment' in item:
                        # hiding the complete list item is cosmetically better than just
                        # hiding the contents (e.g. for sidebar themes).
                        items.append('<li class="toggleCommentsButton" style="display:none;">%s</li>' % item)
                    else:
                        items.append('<li>%s</li>' % item)
            html = u'<ul class="editbar">%s</ul>\n' % ''.join(items)
            self._cache['editbar'] = html

        return html


    def editbarItems(self, page):
        """ Return list of items to show on the editbar

        This is separate method to make it easy to customize the
        edtibar in sub classes.
        """
        _ = self.request.getText
        editbar_actions = []
        for editbar_item in self.request.cfg.edit_bar:
            if (editbar_item == 'Discussion' and
               (self.request.getPragma('supplementation-page', self.request.cfg.supplementation_page)
                                                   in (True, 1, 'on', '1'))):
                    editbar_actions.append(self.supplementation_page_nameLink(page))
            elif editbar_item == 'Edit':
                editbar_actions.append(self.editorLink(page))
            elif editbar_item == 'Info':
                editbar_actions.append(self.infoLink(page))
            elif editbar_item == 'Attachments':
                editbar_actions.append(self.attachmentsLink(page))
            elif editbar_item == 'ActionsMenu':
                editbar_actions.append(self.actionsMenu(page))
        return editbar_actions

    def infoLink(self, page):
        """ Return link to page information """
        if 'info' in self.request.cfg.actions_excluded:
            return ""

        _ = self.request.getText
        return page.link_to(self.request,
                            text=_('Page History'),
                            querystr={'action': 'info'}, css_class='nbinfo', rel='nofollow')
        
def execute(request):
    """
    Generate and return a theme object
        
    @param request: the request object
    @rtype: MoinTheme
    @return: Theme object
    """
    return Theme(request)

